==> haskell-uuid-types-1.0.3-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid-types
version:              1.0.3
visibility:           public
id:                   uuid-types-1.0.3-F34gFgi2LFX9715gXuIbxH
key:                  uuid-types-1.0.3-F34gFgi2LFX9715gXuIbxH
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           aslatter@gmail.com
author:               Antoine Latter
homepage:             https://github.com/aslatter/uuid
synopsis:             Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  a398855e70fe77bfcaafda3cfa1f60e1
exposed:              True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder

import-dirs:          /usr/lib/ghc-8.10.3/site-local/uuid-types-1.0.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/uuid-types-1.0.3
hs-libraries:         HSuuid-types-1.0.3-F34gFgi2LFX9715gXuIbxH
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0 deepseq-1.4.4.0
    hashable-1.3.0.0-KDYgfWb4vLFEllXA1zgjX
    random-1.2.0-30OhcoBMr9kCHjpVnmjVCw text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html:         /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-types-1.0.3-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid-types
version:              1.0.3
visibility:           public
id:                   uuid-types-1.0.3-F8AgAwA0aVwEFO2xlEJTpi
key:                  uuid-types-1.0.3-F8AgAwA0aVwEFO2xlEJTpi
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           aslatter@gmail.com
author:               Antoine Latter
homepage:             https://github.com/aslatter/uuid
synopsis:             Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  11e1bc24c13509a6cc46dfb18b67045d
exposed:              True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder

import-dirs:          /usr/lib/ghc-8.10.4/site-local/uuid-types-1.0.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/uuid-types-1.0.3
hs-libraries:         HSuuid-types-1.0.3-F8AgAwA0aVwEFO2xlEJTpi
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0 deepseq-1.4.4.0
    hashable-1.3.0.0-LJD7TcgV8771CcxcwlhZP8
    random-1.2.0-JTLC2c0pp0nLNcssukvhHY text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html:         /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
